Screenshots
===========

**Using colorise.cprint on Ubuntu**

.. image:: images/cprint_usage_xubuntu.png

**Using colorise.highlight on Windows**

.. image:: images/highlight_usage_win.png

**From left to right: True-color, 256 color and 16 color**

.. image:: images/mario-true-color.png
   :width: 32%
.. image:: images/mario-256-color.png
   :width: 32%
.. image:: images/mario-16-color.png
   :width: 32%
